# -*- coding: utf-8 -*-
import os
import numpy as np
import matplotlib.pyplot as plt
from dspawpy.io.read import get_band_data
from pymatgen.electronic_structure.plotter import BSPlotterProjected

datafile = "dspawpy_proj/dspawpy_tests/inputs/supplement/pband.h5"  # 指定数据文件路径
band_data = get_band_data(
    band_dir=datafile,
    syst_dir=None,  # system.json文件路径，仅当band_dir为json文件时需要
    efermi=None,  # 用于手动修正费米能级
    zero_to_efermi=True,  # 非金属体系应将零点能移动到费米能级
)

bsp = BSPlotterProjected(bs=band_data)  # 初始化BSPlotterProjected类
# ! 选定元素与轨道，创建字典
dict_elem_orbit = {"Mo": ["d"], "S": ["s"]}

axes_or_plt = bsp.get_projected_plots_dots(
    dictio=dict_elem_orbit,
    zero_to_efermi=False,  # 上面读取数据时已经平移，此处应关闭
    ylim=[-8, 5],  # 设置能量范围
    vbm_cbm_marker=False,  # 是否标记导带底和价带顶
)

if isinstance(axes_or_plt, plt.Axes):
    fig = axes_or_plt.get_figure()  # version newer than v2023.8.10
elif np.iterable(axes_or_plt):
    fig = np.asarray(axes_or_plt).flatten()[0].get_figure()
else:
    fig = axes_or_plt.gcf()  # older version pymatgen

# 添加能量零点参考线
for ax in fig.axes:
    ax.axhline(0, lw=2, ls="-.", color="gray")

figname = "dspawpy_proj/dspawpy_tests/outputs/us/4bandplot_elt_orbit.png"  # 输出的能带图文件名
os.makedirs(os.path.dirname(os.path.abspath(figname)), exist_ok=True)
fig.savefig(figname, dpi=300)
